Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py	(revision 7811)
@@ -27,6 +27,6 @@
 from zope.component.interfaces import IFactory
 from zope.interface import Interface, implements
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 optionflags = (
@@ -71,5 +71,5 @@
 stoneville = dict
 
-from waeup.sirp.utils.batching import BatchProcessor
+from waeup.kofa.utils.batching import BatchProcessor
 class CaveProcessor(BatchProcessor):
     util_name = 'caveprocessor'
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py	(revision 7811)
@@ -31,17 +31,17 @@
     Interface, implements, invariant, Invalid, implementedBy)
 
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.university import Faculty
-from waeup.sirp.utils.converters import IObjectConverter
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.interfaces import SimpleSIRPVocabulary
-
-colors = SimpleSIRPVocabulary(
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.university import Faculty
+from waeup.kofa.utils.converters import IObjectConverter
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.interfaces import SimpleKOFAVocabulary
+
+colors = SimpleKOFAVocabulary(
     ('Red', u'red'),
     ('Green', u'green'),
     ('Blue', u'blue'),
     )
-car_nums = SimpleSIRPVocabulary(
+car_nums = SimpleKOFAVocabulary(
     ('None', 0),
     ('One', 1),
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py	(revision 7811)
@@ -18,5 +18,5 @@
 """Register doctests from utils subpackage.
 """
-from waeup.sirp.testing import get_doctest_suite
+from waeup.kofa.testing import get_doctest_suite
 
 def test_suite():
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py	(revision 7811)
@@ -27,5 +27,5 @@
 from zope.security.testing import Principal, Participation
 from zope.security.management import newInteraction, endInteraction
-from waeup.sirp.utils import helpers
+from waeup.kofa.utils import helpers
 
 from zope.interface import Interface, implements
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py	(revision 7811)
@@ -17,5 +17,5 @@
 ##
 
 # Tests for waeup.sirp.utils.logger
 import logging
 import os
@@ -25,8 +25,8 @@
 from zope.component.hooks import setSite, clearSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-
-from waeup.sirp.utils.logger import (
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+
+from waeup.kofa.utils.logger import (
     Logger, MAX_BYTES, BACKUP_COUNT, ILoggerCollector, LoggerCollector,
     ILogger)
@@ -17,5 +17,5 @@
 ##
 
-# Tests for waeup.sirp.utils.logger
+# Tests for waeup.kofa.utils.logger
 import logging
 import os
